==> management-client-1.0.6-sources.jar: com/terracotta/management/services/impl/DfltJerseyClientFactory.java <==
/*
 * All content copyright (c) 2003-2012 Terracotta, Inc., except as may otherwise be noted in a separate copyright
 * notice. All rights reserved.
 */
package com.terracotta.management.services.impl;

import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.config.ClientConfig;
import com.sun.jersey.api.client.filter.ClientFilter;
import com.sun.jersey.client.urlconnection.HTTPSProperties;
import com.terracotta.management.security.SSLContextFactory;
import com.terracotta.management.services.JerseyClientFactory;

import javax.net.ssl.SSLContext;
import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;

/**
 * <p>The default Jersey client factory.</p>
 *
 * @author brandony
 */
public final class DfltJerseyClientFactory implements JerseyClientFactory {
  private final ClientFilter clientFilter;

  private final SSLContextFactory sslCtxtFactory;

  public DfltJerseyClientFactory(ClientFilter clientFilter,
                                 SSLContextFactory sslCtxtFactory) {
    this.clientFilter = clientFilter;
    this.sslCtxtFactory = sslCtxtFactory;
  }

  @Override
  public Client createClient(ClientConfig clientConfig) {
    URI baseURI = (URI)clientConfig.getProperties().get(CLIENT_BASE_URI);
    if (sslCtxtFactory != null && baseURI.getScheme().equalsIgnoreCase("https")) {
      SSLContext sslCtxt;
      try {
        sslCtxt = sslCtxtFactory.create();
      } catch (NoSuchAlgorithmException e) {
        throw new RuntimeException(
            "Failure instantiating TMS Jersey client due to invalid KeyManagerFactory algorithm.", e);
      } catch (IOException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to inability to load keyStore.", e);
      } catch (KeyStoreException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to invalid KeyStore type.", e);
      } catch (CertificateException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to invalid certificates in a KeyStore.",
            e);
      } catch (UnrecoverableKeyException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to bad key in a KeyStore.", e);
      } catch (KeyManagementException e) {
        throw new RuntimeException(
            "Failure instantiating TMS Jersey client due to one or more invalid keys in a KeyStore.", e);
      } catch (URISyntaxException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to bad store location.", e);
      }

      if (sslCtxt != null) {
        clientConfig.getProperties().put(HTTPSProperties.PROPERTY_HTTPS_PROPERTIES, new HTTPSProperties(null, sslCtxt));
      }
    }

    Client c = Client.create(clientConfig);

    c.addFilter(clientFilter);

    return c;
  }
}

==> management-client-1.1.0-sources.jar: com/terracotta/management/services/impl/DfltJerseyClientFactory.java <==
/*
 * All content copyright (c) 2003-2012 Terracotta, Inc., except as may otherwise be noted in a separate copyright
 * notice. All rights reserved.
 */
package com.terracotta.management.services.impl;

import com.sun.jersey.api.client.Client;
import com.sun.jersey.api.client.config.ClientConfig;
import com.sun.jersey.api.client.filter.ClientFilter;
import com.sun.jersey.client.urlconnection.HTTPSProperties;
import com.terracotta.management.security.SSLContextFactory;
import com.terracotta.management.services.JerseyClientFactory;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;

import java.io.IOException;
import java.net.URI;
import java.net.URISyntaxException;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.UnrecoverableKeyException;
import java.security.cert.CertificateException;

/**
 * <p>The default Jersey client factory.</p>
 *
 * @author brandony
 */
public final class DfltJerseyClientFactory implements JerseyClientFactory {
  private final ClientFilter clientFilter;

  private final SSLContextFactory sslCtxtFactory;

  public DfltJerseyClientFactory(ClientFilter clientFilter,
                                 SSLContextFactory sslCtxtFactory) {
    this.clientFilter = clientFilter;
    this.sslCtxtFactory = sslCtxtFactory;
  }

  @Override
  public Client createClient(ClientConfig clientConfig) {
    URI baseURI = (URI)clientConfig.getProperties().get(CLIENT_BASE_URI);
    if (sslCtxtFactory != null && baseURI.getScheme().equalsIgnoreCase("https")) {
      SSLContext sslCtxt;
      try {
        sslCtxt = sslCtxtFactory.create();
      } catch (NoSuchAlgorithmException e) {
        throw new RuntimeException(
            "Failure instantiating TMS Jersey client due to invalid KeyManagerFactory algorithm.", e);
      } catch (IOException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to inability to load keyStore.", e);
      } catch (KeyStoreException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to invalid KeyStore type.", e);
      } catch (CertificateException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to invalid certificates in a KeyStore.",
            e);
      } catch (UnrecoverableKeyException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to bad key in a KeyStore.", e);
      } catch (KeyManagementException e) {
        throw new RuntimeException(
            "Failure instantiating TMS Jersey client due to one or more invalid keys in a KeyStore.", e);
      } catch (URISyntaxException e) {
        throw new RuntimeException("Failure instantiating TMS Jersey client due to bad store location.", e);
      }

      HostnameVerifier hostnameVerifier;
      if (Boolean.getBoolean("tc.ssl.disableHostnameVerifier")) {
        hostnameVerifier = new HostnameVerifier() {
          @Override
          public boolean verify(String hostname, SSLSession session) {
            return true;
          }
        };
      } else {
        //DEV-8842 : returning false every time means :
        // we don't allow the hostname to be different from what is configured in the cert.
        hostnameVerifier = HttpsURLConnection.getDefaultHostnameVerifier();
      }

      clientConfig.getProperties().put(HTTPSProperties.PROPERTY_HTTPS_PROPERTIES, new HTTPSProperties(hostnameVerifier, sslCtxt));
    }

    Client c = Client.create(clientConfig);

    c.addFilter(clientFilter);

    return c;
  }
}
